@@ -59,7 +59,8 @@ class SmartDriver(SeleniumDriverCore):
             screenshotBase64 = self.driver.get_screenshot_as_base64()
         return screenshotBase64
 
-    def process_exist_screenshot_response(self, element_name, key, msg, tresp_data):
+
+    def process_exist_screenshot_response(self, element_name, key, msg, tresp_data, is_backup=False):
         if self.debug:
             print(f'Found cached box in action info for {element_name} using that')
         element_box = tresp_data['predicted_element']
@@ -74,9 +75,14 @@ class SmartDriver(SeleniumDriverCore):
             parent_elem = real_elem.parent
         element = ai_elem(parent_elem, real_elem, element_box, self.driver,
                           self.multiplier)
+        try:
+            real_xpath = self._generate_xpath(element)
+            self._send_warning(real_xpath, element_name, key, tresp_data, is_backup=is_backup)
+        except Exception as e:
+            log.debug(e)
         return element, key, msg
 
-    def _classify(self, element_name):
+    def _classify(self, element_name, is_backup=True):
         msg = ''
         if self.test_case_creation_mode:
             self._test_case_upload_screenshot(element_name)
@@ -139,7 +145,7 @@ class SmartDriver(SeleniumDriverCore):
                     resp_data = self._check_screenshot_exists(key, element_name)
                 if resp_data['success'] and 'predicted_element' in resp_data and resp_data[
                     'predicted_element'] is not None:
-                    return self.process_exist_screenshot_response(element_name, key, msg, resp_data)
+                    return self.process_exist_screenshot_response(element_name, key, msg, resp_data, is_backup=is_backup)
 
             source = ''
 
@@ -149,7 +155,8 @@ class SmartDriver(SeleniumDriverCore):
                         'source': source,
                         'api_key': self.api_key,
                         'label': element_name,
-                        'test_case_name': self.test_case_uuid}
+                        'test_case_name': self.test_case_uuid,
+                        }
                 classify_url = self.url + '/detect'
                 start = time.time()
                 for _ in range(2):
@@ -185,6 +192,11 @@ class SmartDriver(SeleniumDriverCore):
                     real_elem = self._match_bounding_box_to_selenium_element(element_box, multiplier=self.multiplier)
                     parent_elem = real_elem.parent
                 element = ai_elem(parent_elem, real_elem, element_box, self.driver, self.multiplier)
+                try:
+                    real_xpath = self._generate_xpath(element)
+                    self._send_warning(real_xpath, element_name, key, response, is_backup=is_backup)
+                except Exception as e:
+                    log.debug(e)
             except Exception as e:
                 log.error(e)
                 logging.exception('exception during classification')
