@@ -351,7 +351,7 @@ class SeleniumDriverCore(object):
 
                 element = driver.find_by_element_name('some_label')
         """
-        el, key, msg = self._classify(element_name)
+        el, key, msg = self._classify(element_name, is_backup=False)
 
         if el is None:
             print(msg)
@@ -501,7 +501,6 @@ class SeleniumDriverCore(object):
                 screenshot_uuid = self.get_screenshot_hash(screenshotBase64)
                 self.page_offset = self.driver.execute_script('return window.pageYOffset')
                 ActionChains(self.driver).scroll_by_amount(0, int(self.previous_page_offset - self.page_offset)).perform()
-                self.page_offset = self.driver.execute_script('return window.pageYOffset')
 
         # Check results
         try:
@@ -620,5 +619,75 @@ class SeleniumDriverCore(object):
         else:
             return False
 
+    def _send_warning(self, real_xpath, label, screenshot_uuid, resp_data, is_backup=False):
+        element_box = resp_data.get('predicted_element')
+        score = resp_data.get('score', None)
+        message = resp_data['message']
+        if is_backup:
+            warning_type = 'backup_triggered'
+        else:
+            warning_type = 'find_by_ai'
+        data = {'real_xpath': real_xpath, 'label': label, 'screenshot_uuid': screenshot_uuid, 'api_key': self.api_key,
+                'warning_type': warning_type,
+                'predicted_element': element_box, 'score': score, 'message': message}
+        r = requests.post(self.url + '/save_warning', json=data, verify=False)
+
+    def _generate_xpath(self, element):
+        return self.driver.execute_script(
+            "function absoluteXPath(element) {" +
+            "var comp, comps = [];" +
+            "var parent = null;" +
+            "var xpath = '';" +
+            "var getPos = function(element) {" +
+            "var position = 1, curNode;" +
+            "if (element.nodeType == Node.ATTRIBUTE_NODE) {" +
+            "return null;" +
+            "}" +
+            "for (curNode = element.previousSibling; curNode; curNode = curNode.previousSibling) {" +
+            "if (curNode.nodeName == element.nodeName) {" +
+            "++position;" +
+            "}" +
+            "}" +
+            "return position;" +
+            "};" +
+
+            "if (element instanceof Document) {" +
+            "return '/';" +
+            "}" +
+
+            "for (; element && !(element instanceof Document); element = element.nodeType == Node.ATTRIBUTE_NODE ? element.ownerElement : element.parentNode) {" +
+            "comp = comps[comps.length] = {};" +
+            "switch (element.nodeType) {" +
+            "case Node.TEXT_NODE:" +
+            "comp.name = 'text()';" +
+            "break;" +
+            "case Node.ATTRIBUTE_NODE:" +
+            "comp.name = '@' + element.nodeName;" +
+            "break;" +
+            "case Node.PROCESSING_INSTRUCTION_NODE:" +
+            "comp.name = 'processing-instruction()';" +
+            "break;" +
+            "case Node.COMMENT_NODE:" +
+            "comp.name = 'comment()';" +
+            "break;" +
+            "case Node.ELEMENT_NODE:" +
+            "comp.name = element.nodeName;" +
+            "break;" +
+            "}" +
+            "comp.position = getPos(element);" +
+            "}" +
+
+            "for (var i = comps.length - 1; i >= 0; i--) {" +
+            "comp = comps[i];" +
+            "xpath += '/' + comp.name.toLowerCase();" +
+            "if (comp.position !== null) {" +
+            "xpath += '[' + comp.position + ']';" +
+            "}" +
+            "}" +
+
+            "return xpath;" +
+
+            "} return absoluteXPath(arguments[0]);", element)
+
 class NoElementFoundException(Exception):
     pass
\ No newline at end of file
